@@ -82,9 +82,9 @@ DayMatrix::~DayMatrix()
 /******************************************************************************
 * Return all selected dates from mSelStart to mSelEnd, in date order.
 */
-QVector<QDate> DayMatrix::selectedDates() const
+QList<QDate> DayMatrix::selectedDates() const
 {
-    QVector<QDate> selDays;
+    QList<QDate> selDays;
     if (mSelStart != NO_SELECTION)
     {
         selDays.reserve(mSelEnd - mSelStart + 1);
@@ -216,7 +216,7 @@ void DayMatrix::updateEvents(const Resource& resource)
     const KADateTime to(mStartDate.addDays(NUMDAYS-1), QTime(23,59,0), Preferences::timeSpec());
 
     mEventDates.clear();
-    const QVector<Resource> resources = Resources::enabledResources(CalEvent::ACTIVE);
+    const QList<Resource> resources = Resources::enabledResources(CalEvent::ACTIVE);
     for (const Resource& res : resources)
     {
         if (!resource.isValid()  ||  res.id() == resource.id())
@@ -248,7 +248,7 @@ void DayMatrix::updateEvents(const Resource& resource, const KADateTime& before,
             DateTime nextDt;
             for (KADateTime from = before;  ;  )
             {
-                event.nextOccurrence(from, nextDt, KAEvent::RETURN_REPETITION);
+                event.nextOccurrence(from, nextDt, KAEvent::Repeats::Return);
                 if (!nextDt.isValid())
                     break;
                 from = nextDt.effectiveKDateTime().toTimeSpec(timeSpec);
@@ -387,11 +387,7 @@ void DayMatrix::mousePressEvent(QMouseEvent* e)
     {
         if (i < mSelStart  ||  i > mSelEnd)
             setMouseSelection(i, i, true);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         popupMenu(e->globalPosition().toPoint());
-#else
-        popupMenu(e->globalPos());
-#endif
     }
     else if (e->button() == Qt::LeftButton)
     {
@@ -462,7 +458,7 @@ void DayMatrix::setMouseSelection(int start, int end, bool emitSignal)
 
     if (emitSignal)
     {
-        const QVector<QDate> dates = selectedDates();
+        const QList<QDate> dates = selectedDates();
         if (dates != mLastSelectedDates)
         {
             mLastSelectedDates = dates;
@@ -678,4 +674,6 @@ QColor TextColours::getShadedColour(const QColor& colour, bool enabled) const
     return shaded;
 }
 
+#include "moc_daymatrix.cpp"
+
 // vim: et sw=4:
